`DebOps API`_
~~~~~~~~~~~~~

|Travis CI|

.. |Travis CI| image:: https://img.shields.io/travis/debops/debops-api.svg?style=flat
   :target: https://travis-ci.org/debops/debops-api

The public DebOps API is used internally by the DebOps Project but can also be
used by third parties.

Refer to the `DebOps API documentation`_ for more details.
If you want to set up a DebOps API server, checkout the Ansible role debops.debops_api_.

.. _DebOps API: https://api.debops.org/
.. _DebOps API documentation: https://docs.debops.org/en/latest/debops-api/index.html
.. _debops.debops_api: https://github.com/debops/ansible-debops_api
